#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_REMAINDER_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_REMAINDER_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/remainder.hpp>

#endif
